%bcond_with git
%if %{with git}
%define gitdate 20120228
%endif
# Use nouveau driver by default
%bcond_with nouveau


Name:		bumblebee
Summary:	Support for NVidia Optimus laptops on Linux
Group:		System/Kernel and hardware
Version:	3.2.1
Release:	11
License:	GPLv3
URL:		https://github.com/Bumblebee-Project/bumblebee
# source from git repo git://github.com/Bumblebee-Project/Bumblebee.git
# we need to change to develop branch to allow changing to nouveau without
# using nvidia paths
#Source0:	https://github.com/downloads/Bumblebee-Project/Bumblebee/%{name}-%{!?with_git:%{version}}%{?with_git:%{gitdate}}.tar.%{?with_git:xz}%{!?with_git:gz}
Source0:	http://bumblebee-project.org/%{name}-%{version}.tar.gz

# Patch series from https://github.com/arafey/Bumblebee.
# Should fix automatic unload of nvidia-modeset, nvidia-uvm and nvidia-drm
# with the newer NVidia drivers.
# http://bugs.rosalinux.ru/show_bug.cgi?id=6976
Patch0:		0001-Dirty-fix-for-issue-699.patch
Patch1:		0002-Added-nvidia_modeset-detection-for-issue-699.patch
Patch2:		0003-Fix-nvidia_uvm-just-like-nvidia_modeset.patch
Patch3:		0004-Workaround-for-nvidia_drm-in-newer-drivers.patch

# Additional patch to fix the previous ones
Patch4:		0005-Unload-modules-one-by-one-and-in-the-correct-order.patch

BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libbsd)
BuildRequires:	help2man
Requires(pre):	update-alternatives
Requires(post):	systemd-units
Requires(preun):systemd-units
Requires(pre):	rpm-helper
Requires:	VirtualGL
Requires:	%mklibname VirtualGL
%if %{with nouveau}
Requires:	x11-driver-video-nouveau
%else
# NOTE: Install preferred version of NVIDIA driver via XFdrake
# Requires:	x11-driver-video-nvidia-current
%endif
Requires:	kmod(bbswitch)

%description
Bumblebee daemon is a rewrite of the original Bumblebee service, providing
an elegant and stable means of managing Optimus hybrid graphics chip sets.
A primary goal of this project is to not only enable use of the discrete
GPU for rendering, but also to enable smart power management of the dGPU
when it's not in use.

%files
%doc README.markdown doc/RELEASE_NOTES_3_2_1 README.install.urpmi
%{_sysconfdir}/bash_completion.d/bumblebee
%dir %{_sysconfdir}/bumblebee/
%dir %{_sysconfdir}/bumblebee/xorg.conf.d/
%config(noreplace) %{_sysconfdir}/bumblebee/bumblebee.conf
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nouveau
%config(noreplace) %{_sysconfdir}/bumblebee/xorg.conf.nvidia
/lib/systemd/system/bumblebeed.service
%{_sbindir}/bumblebeed
%{_bindir}/optirun
%{_bindir}/bumblebee-bugreport
%{_mandir}/man1/bumblebeed.1.*
%{_mandir}/man1/optirun.1.*
%{_sysconfdir}/bumblebee/xorg.conf.d/10-dummy.conf
%{_sysconfdir}/bumblebee/modprobe.conf
/lib/udev/rules.d/99-bumblebee-nvidia-dev.rules

%pre
%_pre_groupadd %{name}
if [ "$1" -eq "1" ];then
  users=$(getent passwd | awk -F: '$3 >= 500 && $3 < 60000 {print $1}')
  for user in $users; do
    gpasswd -a $user bumblebee
  done
  /usr/sbin/update-alternatives --set gl_conf %{_sysconfdir}/ld.so.conf.d/GL/standard.conf
fi

%post
# blacklist nouveau
grub2-cfg-mod --add "rdblacklist=nouveau"
update-grub2
# run bumblebeed
%_post_service bumblebeed
# Simple: still needs this since in release 3 services were not set
# enabled and seams that still isnt properly handeled in %%_post_service
if [ "$1" -ge "1" ]; then
  # Enable (but don't start) the unit by default
  /bin/systemctl enable bumblebeed.service
  # Start bumblebeed service
  /bin/systemctl start bumblebeed.service
fi

%preun
%_preun_service bumblebeed

%postun
# We need this since "%%_postun_groupdel %%{name}" doesnt remove the group if
# set to a user
if [ "$1" -eq "0" ];then
  /usr/sbin/groupdel bumblebee
fi
# un-blacklist nouveau on uninstall
if [ "$1" -eq "0" ];then
  grub2-cfg-mod --del "rdblacklist=nouveau"
  update-grub2
fi

# Simple: we need to ensure bumblebee group isnt removed when upgrading
# This doesnt need exist for Mageia 2
%triggerpostun -- %{name} < 3.0-9
%_pre_groupadd %{name}
users=$(getent passwd | awk -F: '$3 >= 500 && $3 < 60000 {print $1}')
for user in $users; do
  gpasswd -a $user bumblebee
done

#--------------------------------------------------------------------
%prep
%setup -q%{?with_git:n %{name}}
%apply_patches

cat > README.install.urpmi <<EOF
Use XFdrake to configure X to use the correct NVIDIA driver. Any needed
packages will be automatically installed if not already present.

1. Run XFdrake
2. Go to the Video Driver list
3. Select the preferred driver from the list
4. Reboot

%build
%{?with_git:NOCONFIGURE=1 autoreconf -fi}
%configure2_5x \
%if %{with nouveau}
CONF_DRIVER=nouveau \
%else
CONF_DRIVER=nvidia \
CONF_DRIVER_MODULE_NVIDIA=nvidia \
%endif
CONF_KEEPONEXIT=true \
CONF_TURNOFFATEXIT=false \
CONF_PM_METHOD=auto \
%ifarch x86_64
CONF_LDPATH_NVIDIA=%{_usr}/lib/nvidia:%{_libdir}/nvidia \
CONF_MODPATH_NVIDIA=%{_usr}/lib/nvidia/xorg,%{_libdir}/nvidia/xorg,%{_usr}/lib/xorg/modules,%{_libdir}/xorg/modules,%{_usr}/lib/xorg/extra-modules,%{_usr}/xorg/extra-modules
%else
CONF_LDPATH_NVIDIA=%{_usr}/lib/nvidia \
CONF_MODPATH_NVIDIA=%{_usr}/lib/nvidia/xorg,%{_usr}/lib/xorg/modules,%{_usr}/lib/xorg/extra-modules
%endif

%make

%install
rm -rf %{buildroot}
%makeinstall_std
echo "nvidia && bumblebee" > %{buildroot}%{_sysconfdir}/bumblebee/modprobe.conf

install -D -m644 scripts/systemd/bumblebeed.service %{buildroot}/lib/systemd/system/bumblebeed.service

%changelog

* Wed Feb 15 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3.2.1-11
- (e333f59) MassBuild#1250: Increase release tag


